==> huaweicloudsdkrds-3.0.49-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/pwd_reset_request.py <==
# coding: utf-8

import pprint
import re

import six





class PwdResetRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'db_user_pwd': 'str'
    }

    attribute_map = {
        'db_user_pwd': 'db_user_pwd'
    }

    def __init__(self, db_user_pwd=None):
        """PwdResetRequest - a model defined in huaweicloud sdk"""
        
        

        self._db_user_pwd = None
        self.discriminator = None

        self.db_user_pwd = db_user_pwd

    @property
    def db_user_pwd(self):
        """Gets the db_user_pwd of this PwdResetRequest.

        数据库密码

        :return: The db_user_pwd of this PwdResetRequest.
        :rtype: str
        """
        return self._db_user_pwd

    @db_user_pwd.setter
    def db_user_pwd(self, db_user_pwd):
        """Sets the db_user_pwd of this PwdResetRequest.

        数据库密码

        :param db_user_pwd: The db_user_pwd of this PwdResetRequest.
        :type: str
        """
        self._db_user_pwd = db_user_pwd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PwdResetRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrds-3.0.52-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/pwd_reset_request.py <==
# coding: utf-8

import re
import six





class PwdResetRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'db_user_pwd': 'str'
    }

    attribute_map = {
        'db_user_pwd': 'db_user_pwd'
    }

    def __init__(self, db_user_pwd=None):
        """PwdResetRequest - a model defined in huaweicloud sdk"""
        
        

        self._db_user_pwd = None
        self.discriminator = None

        self.db_user_pwd = db_user_pwd

    @property
    def db_user_pwd(self):
        """Gets the db_user_pwd of this PwdResetRequest.

        数据库密码

        :return: The db_user_pwd of this PwdResetRequest.
        :rtype: str
        """
        return self._db_user_pwd

    @db_user_pwd.setter
    def db_user_pwd(self, db_user_pwd):
        """Sets the db_user_pwd of this PwdResetRequest.

        数据库密码

        :param db_user_pwd: The db_user_pwd of this PwdResetRequest.
        :type: str
        """
        self._db_user_pwd = db_user_pwd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PwdResetRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
